@@ -19,6 +19,12 @@
 
 //#define DEBUG
 
+// Minimal wa php script version requested
+#define WA_VERSION 2
+
 #define CR_SERVER_LOST 2013
 
+#define TRUE 1
+#define FALSE 0
+
 #endif
